=====================
Chronos deployments
=====================

---------------------
Default template
---------------------

shpkpr includes a set of default templates which are used when a custom template is not supplied by the user at runtime. The default template used for chronos jobs is included below for reference purposes.

.. literalinclude:: ../../shpkpr/resources/templates/chronos/default/job.json.tmpl
  :language: yaml+jinja
